# types-confluent-kafka

This package only contains type hints for the `confluent-kafka` python package. It may be useful to add type checking for `mypy`, or autocompletion in your *language server*.

This package is not endorsed by Confluent.

## Installation

The package can be installed from [PyPI](https://pypi.org/project/types-confluent-kafka/)

```bash
pip install types-confluent-kafka
```

alternatively
```
mypy ./your_codebase
mypy --install-types
```
